from datetime import timedelta

from flask import Flask
from flask_sqlalchemy import SQLAlchemy

from management.data import shared
from portal.database import models
from portal.tools import time


def init_cpp_data(app: Flask, db: SQLAlchemy):
    with app.app_context():
        factory = shared.DataFactory(db)
        # course
        test_course1 = factory.create_course(codename='PB161', name='Programování v jazyce C++')

        # groups
        tc1_students = factory.create_group(course=test_course1, name="seminar01")
        tc1_teachers = factory.create_group(course=test_course1, name="teachers")

        tc1_hw01 = factory.create_project(
            course=test_course1, name="HW01", codename='hw01', config=dict(
                file_whitelist="*.*",
                test_files_source='https://gitlab.fi.muni.cz/grp-kontr2/testing/hello-test-files',
                test_files_subdir='',
                pre_submit_script="python for kontr pre",
                post_submit_script="python for kontr post",
                submission_scheduler_config="python for sub Q",
                submission_parameters="{\"type\":\"text\"}",
                submissions_allowed_from=time.current_time() - timedelta(days=1),
                submissions_allowed_to=time.current_time() + timedelta(days=10),
                archive_from=time.current_time() + timedelta(days=30)
            )
        )

        # roles
        tc1_student = factory.scaffold_role(role_type='student', course=test_course1)
        tc1_teacher = factory.scaffold_role(role_type='teacher', course=test_course1)
        tc1_owner = factory.scaffold_role(role_type='owner', course=test_course1)
        tc1_worker = factory.scaffold_role(role_type='worker', course=test_course1)

        # Projects in groups
        tc1_students.projects.append(tc1_hw01)
        db.session.add_all([tc1_student, tc1_teacher, tc1_owner, tc1_teachers])

        # workers
        worker = factory.create_worker(name='worker', url='http://localhost:8080')
        worker.secrets.append(models.Secret('executor_secret', 'executor_secret'))
        worker.roles.append(tc1_worker)
        db.session.add_all([worker])
        # Commit to the DB
        db.session.commit()
